from django import forms

from .widgets import (
    MartorWidget,
    AdminMartorWidget,
)


class MartorFormField(forms.CharField):

    def __init__(self, *args, **kwargs):
        kwargs['label'] = ''  # To set without label.
        super(MartorFormField, self).__init__(*args, **kwargs)

        if not issubclass(self.widget.__class__, MartorWidget):
            self.widget = MartorWidget()



from django.conf.urls import url
from .views import (
    markdownfy_view,
    markdown_imgur_uploader,
    markdown_search_user
)

urlpatterns = [
    url(
        r'^markdownify/$',
        markdownfy_view,
        name='martor_markdownfy'
    ),
    url(
        r'^uploader/$',
        markdown_imgur_uploader,
        name='imgur_uploader'
    ),
    url(
        r'^search-user/$',
        markdown_search_user,
        name='search_user_json'
    ),
]
